==> xld-devops-as-code-24.3.0-710.1425-sources.jar: com/xebialabs/deployit/ascode/service/spec/UsersSpecInterpreter.scala <==
package com.xebialabs.deployit.ascode.service.spec

import com.xebialabs.ascode.service.spec.{InterpreterContext, SpecInterpreter}
import com.xebialabs.ascode.yaml.dto.AsCodeResponse
import com.xebialabs.ascode.yaml.dto.AsCodeResponse.EntityKinds._
import com.xebialabs.ascode.yaml.model.UsersSpec
import com.xebialabs.ascode.yaml.model.{User => XLDUser}
import com.xebialabs.deployit.core.rest.api.UserResource
import com.xebialabs.deployit.engine.api.security.User
import com.xebialabs.deployit.exception.NotFoundException
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Component

@Component
@Autowired
class UsersSpecInterpreter(userResource: UserResource) extends SpecInterpreter with Logging {
  override def isDefinedAt(context: InterpreterContext): Boolean = context.definition.spec.isInstanceOf[UsersSpec]

  override def apply(context: InterpreterContext): AsCodeResponse = {
    val spec = context.definition.spec.asInstanceOf[UsersSpec]
    AsCodeResponse.ids(spec.users.foldLeft(USER.ids) {
      case (acc, user: XLDUser) =>
        try {
          val foundUser = userResource.read(user.username)
          foundUser.setPassword(user.password)
          userResource.modifyPassword(user.username, foundUser)
          acc.withUpdated(user.username)
        } catch {
          case _: NotFoundException =>
            logger.warn(s"User not found so creating user ${user.username}")
            userResource.create(user.username, UserUtils.asCodeUserToUser(user))
            acc.withCreated(user.username)
        }
      case (acc, _) => acc
    })
  }
}

object UserUtils {
  def asCodeUserToUser(xldUser: XLDUser): User = {
    val user = new User(xldUser.username, false)
    user.setPassword(xldUser.password)
    user
  }
}

==> xld-devops-as-code-24.3.14-1228.130-sources.jar: com/xebialabs/deployit/ascode/service/spec/UsersSpecInterpreter.scala <==
package com.xebialabs.deployit.ascode.service.spec

import com.xebialabs.ascode.service.spec.{InterpreterContext, SpecInterpreter}
import com.xebialabs.ascode.yaml.dto.AsCodeResponse
import com.xebialabs.ascode.yaml.dto.AsCodeResponse.EntityKinds._
import com.xebialabs.ascode.yaml.model.UsersSpec
import com.xebialabs.deployit.ascode.yaml.model.user.XLDUser
import com.xebialabs.deployit.core.rest.api.UserResource
import com.xebialabs.deployit.engine.api.security.{User, UserProfile}
import com.xebialabs.deployit.exception.NotFoundException
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Component

@Component
@Autowired
class UsersSpecInterpreter(userResource: UserResource) extends SpecInterpreter with Logging {
  override def isDefinedAt(context: InterpreterContext): Boolean = context.definition.spec.isInstanceOf[UsersSpec]

  override def apply(context: InterpreterContext): AsCodeResponse = {
    val spec = context.definition.spec.asInstanceOf[UsersSpec]
    AsCodeResponse.ids(spec.users.foldLeft(USER.ids) {
      case (acc, user: XLDUser) =>
        try {
          val foundUser = userResource.read(user.username)
          foundUser.setPassword(user.password)
          foundUser.getUserProfile.setEmail(if (user.email.exists(_.nonEmpty)) user.email.get else null)
          foundUser.getUserProfile.setFullName(if (user.name.exists(_.nonEmpty)) user.name.get else null)
          foundUser.getUserProfile.setLoginAllowed(user.enabled)
          userResource.updateUser(user.username, foundUser)
          acc.withUpdated(user.username)
        } catch {
          case _: NotFoundException =>
            logger.warn(s"User not found so creating user ${user.username}")
            userResource.create(user.username, UserUtils.asCodeUserToUser(user))
            acc.withCreated(user.username)
        }
      case (acc, _) => acc
    })
  }
}

object UserUtils {
  def asCodeUserToUser(xldUser: XLDUser): User = {
    val user = new User(xldUser.username, false)
    user.setPassword(xldUser.password)
    val profile = new UserProfile()
    profile.setEmail(if (xldUser.email.exists(_.nonEmpty)) xldUser.email.get else null)
    profile.setFullName(if (xldUser.name.exists(_.nonEmpty)) xldUser.name.get else null)
    profile.setLoginAllowed(xldUser.enabled)
    profile.setIsInternal(true)
    user.setUserProfile(profile)
    user
  }
}
